local toc, privateData = ...
local AddonId = toc.identifier

RT = {}
RT.display = {}

local function systemUpdate()

	local config = wtxGadgets.RandomTitle1

	if not config or not config.NextUpdate then return end
	
	if Inspect.Time.Server() > config.NextUpdate then
		--print("times match " .. Inspect.Time.Server() .. " == " .. config.NextUpdate)
		updateTitle()
	else
		--print("times dont match " .. Inspect.Time.Server() .. " ~= " .. config.NextUpdate)
	end

end

local function addTitle(titles)

	local config = wtxGadgets.RandomTitle1

	if config then
		for id,status in pairs(titles) do
			for slot,category in ipairs(config.Category.Prefix) do
				if Inspect.Title.Detail(id).category == category and Inspect.Title.Detail(id).prefix then
					table.insert(config.Title.Prefix, id)
				end
			end
			for slot,category in ipairs(config.Category.Suffix) do
				if Inspect.Title.Detail(id).category == category and not Inspect.Title.Detail(id).prefix then
					table.insert(config.Title.Suffix, id)
				end
			end
		end
	end

end

local function Create(configuration)

	Command.System.Watchdog.Quiet()
	
	if WT.Gadgets.RandomTitle1 then
		Command.Console.Display("general", false, "Only one Random Title Gadget is allowed at a time", false)
		return
	end
	
	RT.display[configuration.id] = UI.CreateFrame("Frame", AddonId .. "_display_" .. configuration.id, WT.Context)
		RT.display[configuration.id]:SetPoint("TOPLEFT", UIParent, "TOPLEFT", 350, 350)
		RT.display[configuration.id]:SetWidth(50)
		RT.display[configuration.id]:SetHeight(50)
		RT.display[configuration.id]:SetLayer(5)
		RT.display[configuration.id]:SetVisible(false)
	
	local config = wtxGadgets.RandomTitle1
	
	if config == nil then
		configuration = updateTitle(configuration)
	else
		configuration = updateTitle(config)
	end
	
	return RT.display[configuration.id]
	
end

local function Modify(configuration)

	configuration = updateTitle(configuration)

	return RT.display[configuration.id]

end

function updateTitle(configuration)

	local config = wtxGadgets.RandomTitle1
	
	if config == nil then
		config = WT.Gadgets.RandomTitle1
		if config == nil and configuration then
			config = configuration
		end
	end

	local pre, suf
	math.randomseed(os.time())
	pre = math.random(0,#config.Title.Prefix)
	suf = math.random(0,#config.Title.Suffix)
	
	if pre == 0 then
		Command.Title.Prefix(nil)
	else
		Command.Title.Prefix(config.Title.Prefix[pre])
	end
	
	if suf == 0 then
		Command.Title.Suffix(nil)
	else
		Command.Title.Suffix(config.Title.Suffix[suf])
	end
	
	--Currently if you set this to a really small time then increase it later it will cause it to fire very infrequently
	--This may not be an issue if the CreatedTime is modified when updating via interface.
	if config.Interval.Type == "Specific" then
		local curTime = Inspect.Time.Server()
		if not config.NextUpdate then
			config.NextUpdate = config.CreateTime + config.Interval.Unix
		end
		if config.NextUpdate < curTime then
			--local timeDif = curTime - config.CreateTime
			--local timeDifFactor = timeDif / config.Interval.Unix
			--config.Interval.Count = math.floor(timeDifFactor)
			config.NextUpdate = config.NextUpdate + config.Interval.Unix
		end
		--config.Interval.Count = config.Interval.Count + 1
	elseif config.Interval.Type == "Random" then
		local day, hour, minute
		math.randomseed(os.time())
		day = math.random(0,11)
		hour = math.random(0,24)
		minute = math.random(11)
		local minutes = { "1", "2", "3", "4", "5", "10", "15", "20", "25", "30", "35", "40", "45", "50", "55" }
		config.Interval.Days = day
		config.Interval.Hours = hour
		config.Interval.Minutes = minutes[minute]
		config.Interval.Unix = (config.Interval.Days*86400)+(config.Interval.Hours*3600)+(config.Interval.Minutes*60)
		config.NextUpdate = Inspect.Time.Server() + config.Interval.Unix
	end
	
	--Command.Console.Display("general", false, "Current Displayed Name: " .. (Inspect.Unit.Detail("player").titlePrefixName or "") .. " " .. Inspect.Unit.Detail("player").name .. (Inspect.Unit.Detail("player").titleSuffixName or ""), false)
	
	wtxGadgets.RandomTitle1 = config
	
	return config
	
end


local dialog = false

local function ConfigDialog(container)

	Command.System.Watchdog.Quiet()
	
	RT.container = container
	
	RT.label = UI.CreateFrame("Text", AddonId .. "_label", container)
		RT.label:SetPoint("TOPLEFT", container, "TOPLEFT")
		RT.label:SetPoint("RIGHT", container, "RIGHT")
		RT.label:SetFontSize(12)
		RT.label:SetText("A simple addon that will change your title on a specified time to a new random one.")
		
	RT.Time = UI.CreateFrame("Frame", AddonId .. "_Time", container)
		RT.Time:SetPoint("TOPLEFT", RT.label, "BOTTOMLEFT", 0, 5)
		RT.Time:SetPoint("RIGHT", container, "RIGHT")
		RT.Time:SetHeight(20)
		
		RT.Time.label = UI.CreateFrame("Text", AddonId .. "_Time_label", RT.Time)
			RT.Time.label:SetText("Time Options:")
			RT.Time.label:SetWidth(200)
			RT.Time.label:SetPoint("TOPLEFT", RT.Time, "TOPLEFT")
			
			RT.Time.Option = {}
		
			RT.Time.Option.label = UI.CreateFrame("Text", AddonId .. "_Time_Option_label", RT.Time)
				RT.Time.Option.label:SetText("Change Interval Type:")
				RT.Time.Option.label:SetPoint("CENTERLEFT", RT.Time.label, "CENTERRIGHT", 69, 0)
		
			RT.Time.Option.value = UI.CreateFrame("Text", AddonId .. "_Time_Option_value", RT.Time)
				RT.Time.Option.value:SetText("Random")
				RT.Time.Option.value:SetWidth(75)
				RT.Time.Option.value:SetBackgroundColor(0.2,0.2,0.2,0.9)
				RT.Time.Option.value:SetPoint("CENTERLEFT", RT.Time.Option.label, "CENTERRIGHT", 5, 0)
			
			RT.Time.Option.Icon = UI.CreateFrame("Texture", AddonId .. "_Time_Option_Icon", RT.Time.Option.value)
				RT.Time.Option.Icon:SetTexture(AddonId, "img/wtDropDown.png")
				RT.Time.Option.Icon:SetHeight(RT.Time.Option.value:GetHeight())
				RT.Time.Option.Icon:SetWidth(RT.Time.Option.value:GetHeight())
				RT.Time.Option.Icon:SetPoint("TOPLEFT", RT.Time.Option.value, "TOPRIGHT", -10, 0)
			RT.Time.Option.menu = WT.Control.Menu.Create(container, { "Random", "Specific" }, 
				function(value) 
					RT.Time.Option.value:SetText(value) 
					if value == "Specific" then
						RT.Time.Change.Days.Icon:SetVisible(true)
						RT.Time.Change.Hours.Icon:SetVisible(true)
						RT.Time.Change.Minutes.Icon:SetVisible(true)
					else
						RT.Time.Change.Days.Icon:SetVisible(false)
						RT.Time.Change.Hours.Icon:SetVisible(false)
						RT.Time.Change.Minutes.Icon:SetVisible(false)
						local day, hour, minute
						math.randomseed(os.time())
						day = math.random(0,11)
						hour = math.random(0,24)
						minute = math.random(11)
						RT.Time.Change.Days.value:SetText(tostring(day))
						RT.Time.Change.Hours.value:SetText(tostring(hour))
						local minutes = { "1", "2", "3", "4", "5", "10", "15", "20", "25", "30", "35", "40", "45", "50", "55" }
						RT.Time.Change.Minutes.value:SetText(minutes[minute])
					end
				end, sort)
				RT.Time.Option.menu:SetPoint("TOPRIGHT", RT.Time.Option.Icon, "BOTTOMCENTER")
			
			RT.Time.Option.Icon.Event.LeftClick = function() RT.Time.Option.menu:Toggle() end
			RT.Time.Option.value.Event.LeftClick = function() RT.Time.Option.menu:Toggle() end
			
			RT.Time.Change = {}

			RT.Time.Change.label = UI.CreateFrame("Text", AddonId .. "_Time_Option_label", RT.label)
				RT.Time.Change.label:SetText("Change Interval:")
				RT.Time.Change.label:SetPoint("TOPLEFT", RT.Time.label, "BOTTOMLEFT", 0, 5)
				
				local day, hour, minute
				math.randomseed(os.time())
				day = math.random(0,11)
				hour = math.random(0,24)
				minute = math.random(11)
				
				RT.Time.Change.Days = {}
				
				RT.Time.Change.Days.label = UI.CreateFrame("Text", AddonId .. "_Time_Change_Days_label", RT.Time.Change.label)
					RT.Time.Change.Days.label:SetText("Days:")
					RT.Time.Change.Days.label:SetPoint("CENTERLEFT", RT.Time.Change.label, "CENTERRIGHT", 30, 0)
		
				RT.Time.Change.Days.value = UI.CreateFrame("Text", AddonId .. "_Time_Change_Days_value", RT.Time.Change.label)
					RT.Time.Change.Days.value:SetText(tostring(day))
					RT.Time.Change.Days.value:SetWidth(50)
					RT.Time.Change.Days.value:SetBackgroundColor(0.2,0.2,0.2,0.9)
					RT.Time.Change.Days.value:SetPoint("CENTERLEFT", RT.Time.Change.Days.label, "CENTERRIGHT", 5, 0)
			
				RT.Time.Change.Days.Icon = UI.CreateFrame("Texture", AddonId .. "_Time_Change_Days_Icon", RT.Time.Change.Days.value)
					RT.Time.Change.Days.Icon:SetTexture(AddonId, "img/wtDropDown.png")
					RT.Time.Change.Days.Icon:SetHeight(RT.Time.Change.Days.value:GetHeight())
					RT.Time.Change.Days.Icon:SetWidth(RT.Time.Change.Days.value:GetHeight())
					RT.Time.Change.Days.Icon:SetPoint("TOPLEFT", RT.Time.Change.Days.value, "TOPRIGHT", -10, 0)
					RT.Time.Change.Days.Icon:SetVisible(false)
				RT.Time.Change.Days.menu = WT.Control.Menu.Create(container, 
					{ "0       ", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10" }, 
					function(value) RT.Time.Change.Days.value:SetText(value) end, sort)
					RT.Time.Change.Days.menu:SetPoint("TOPRIGHT", RT.Time.Change.Days.Icon, "BOTTOMCENTER")
			
				RT.Time.Change.Days.Icon.Event.LeftClick = function() if RT.Time.Option.value:GetText() == "Specific" then RT.Time.Change.Days.menu:Toggle() end end
				RT.Time.Change.Days.value.Event.LeftClick = function() if RT.Time.Option.value:GetText() == "Specific" then RT.Time.Change.Days.menu:Toggle() end end
				
				
				RT.Time.Change.Hours = {}
				
				RT.Time.Change.Hours.label = UI.CreateFrame("Text", AddonId .. "_Time_Change_Hours_label", RT.Time.Change.label)
					RT.Time.Change.Hours.label:SetText("Hours:")
					RT.Time.Change.Hours.label:SetPoint("CENTERLEFT", RT.Time.Change.Days.Icon, "CENTERRIGHT", 20, 0)
		
				RT.Time.Change.Hours.value = UI.CreateFrame("Text", AddonId .. "_Time_Change_Hours_value", RT.Time.Change.label)
					RT.Time.Change.Hours.value:SetText(tostring(hour))
					RT.Time.Change.Hours.value:SetWidth(50)
					RT.Time.Change.Hours.value:SetBackgroundColor(0.2,0.2,0.2,0.9)
					RT.Time.Change.Hours.value:SetPoint("CENTERLEFT", RT.Time.Change.Hours.label, "CENTERRIGHT", 5, 0)
			
				RT.Time.Change.Hours.Icon = UI.CreateFrame("Texture", AddonId .. "_Time_Change_Hours_Icon", RT.Time.Change.Hours.value)
					RT.Time.Change.Hours.Icon:SetTexture(AddonId, "img/wtDropDown.png")
					RT.Time.Change.Hours.Icon:SetHeight(RT.Time.Change.Hours.value:GetHeight())
					RT.Time.Change.Hours.Icon:SetWidth(RT.Time.Change.Hours.value:GetHeight())
					RT.Time.Change.Hours.Icon:SetPoint("TOPLEFT", RT.Time.Change.Hours.value, "TOPRIGHT", -10, 0)
					RT.Time.Change.Hours.Icon:SetVisible(false)
				RT.Time.Change.Hours.menu = WT.Control.Menu.Create(container, 
					{ "0       ", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23" }, 
					function(value) RT.Time.Change.Hours.value:SetText(value) end, sort)
					RT.Time.Change.Hours.menu:SetPoint("TOPRIGHT", RT.Time.Change.Hours.Icon, "BOTTOMCENTER")
			
				RT.Time.Change.Hours.Icon.Event.LeftClick = function() if RT.Time.Option.value:GetText() == "Specific" then RT.Time.Change.Hours.menu:Toggle() end end
				RT.Time.Change.Hours.value.Event.LeftClick = function() if RT.Time.Option.value:GetText() == "Specific" then RT.Time.Change.Hours.menu:Toggle() end end
				
				
				RT.Time.Change.Minutes = {}
				
				RT.Time.Change.Minutes.label = UI.CreateFrame("Text", AddonId .. "_Time_Change_Minutes_label", RT.Time.Change.label)
					RT.Time.Change.Minutes.label:SetText("Minutes:")
					RT.Time.Change.Minutes.label:SetPoint("CENTERLEFT", RT.Time.Change.Hours.Icon, "CENTERRIGHT", 20, 0)
		
				RT.Time.Change.Minutes.value = UI.CreateFrame("Text", AddonId .. "_Time_Change_Minutes_value", RT.Time.Change.label)
					local minutes = { "1", "2", "3", "4", "5", "10", "15", "20", "25", "30", "35", "40", "45", "50", "55" }
					RT.Time.Change.Minutes.value:SetText(minutes[minute])
					RT.Time.Change.Minutes.value:SetWidth(50)
					RT.Time.Change.Minutes.value:SetBackgroundColor(0.2,0.2,0.2,0.9)
					RT.Time.Change.Minutes.value:SetPoint("CENTERLEFT", RT.Time.Change.Minutes.label, "CENTERRIGHT", 5, 0)
			
				RT.Time.Change.Minutes.Icon = UI.CreateFrame("Texture", AddonId .. "_Time_Change_Minutes_Icon", RT.Time.Change.Minutes.value)
					RT.Time.Change.Minutes.Icon:SetTexture(AddonId, "img/wtDropDown.png")
					RT.Time.Change.Minutes.Icon:SetHeight(RT.Time.Change.Minutes.value:GetHeight())
					RT.Time.Change.Minutes.Icon:SetWidth(RT.Time.Change.Minutes.value:GetHeight())
					RT.Time.Change.Minutes.Icon:SetPoint("TOPLEFT", RT.Time.Change.Minutes.value, "TOPRIGHT", -10, 0)
					RT.Time.Change.Minutes.Icon:SetVisible(false)
				RT.Time.Change.Minutes.menu = WT.Control.Menu.Create(container, 
					{ "1       ", "2", "3", "4", "5", "10", "15", "20", "25", "30", "35", "40", "45", "50", "55" }, 
					function(value) RT.Time.Change.Minutes.value:SetText(value) end, sort)
					RT.Time.Change.Minutes.menu:SetPoint("TOPRIGHT", RT.Time.Change.Minutes.Icon, "BOTTOMCENTER")
			
				RT.Time.Change.Minutes.Icon.Event.LeftClick = function() if RT.Time.Option.value:GetText() == "Specific" then RT.Time.Change.Minutes.menu:Toggle() end end
				RT.Time.Change.Minutes.value.Event.LeftClick = function() if RT.Time.Option.value:GetText() == "Specific" then RT.Time.Change.Minutes.menu:Toggle() end end
			
	RT.Filter = UI.CreateFrame("Frame", AddonId .. "_Filter", container)
		RT.Filter:SetPoint("TOPLEFT", RT.Time.Change.label, "BOTTOMLEFT", 0, 5)
		RT.Filter:SetPoint("RIGHT", container, "RIGHT")
	
	RT.FilterList = {}
	RT.FilterList.Prefix = {true, true, true, true, true, true, false}
	RT.FilterList.Suffix = {true, true, true, true, true, true, true}
		
		RT.Filter.label = UI.CreateFrame("Text", AddonId .. "_Filter_label", RT.Filter)
			RT.Filter.label:SetText("Title Category Filter Options:")
			RT.Filter.label:SetPoint("TOPLEFT", RT.Filter, "TOPLEFT")
			
			RT.Filter.Category = UI.CreateFrame("Text", AddonId .. "_Filter_Category", RT.Filter)
				RT.Filter.Category:SetText("Title Catagories:")
				RT.Filter.Category:SetPoint("TOPLEFT", RT.Filter.label, "BOTTOMLEFT", 15, 15)
				
			RT.Filter.Prefix = UI.CreateFrame("Text", AddonId .. "_Filter_Prefix", RT.Filter)
				RT.Filter.Prefix:SetText("Prefix:")
				RT.Filter.Prefix:SetPoint("TOPLEFT", RT.Filter.Category, "TOPRIGHT", 100, 0)
				
			RT.Filter.Suffix = UI.CreateFrame("Text", AddonId .. "_Filter_Suffix", RT.Filter)
				RT.Filter.Suffix:SetText("Suffix:")
				RT.Filter.Suffix:SetPoint("TOPLEFT", RT.Filter.Prefix, "TOPRIGHT", 30, 0)
			
			
			RT.Filter.Category.Faction = UI.CreateFrame("Text", AddonId .. "_Filter_Category_Faction", RT.Filter.Category)
				RT.Filter.Category.Faction:SetPoint("TOPLEFT", RT.Filter.Category, "BOTTOMLEFT", 0, 5)
				RT.Filter.Category.Faction:SetFontColor(1,1,1,1)
				RT.Filter.Category.Faction:SetFontSize(12)
				RT.Filter.Category.Faction:SetVisible(true)
				RT.Filter.Category.Faction:SetText("Faction:")
			
			RT.Filter.Prefix.Faction = UI.CreateFrame("RiftCheckbox", AddonId .. "_Filter_Prefix_Faction", RT.Filter.Category.Faction)
				RT.Filter.Prefix.Faction:SetPoint("TOPLEFT", RT.Filter.Prefix, "BOTTOMLEFT", 5, 5)
				RT.Filter.Prefix.Faction:SetHeight(20)
				RT.Filter.Prefix.Faction:SetWidth(20)
				RT.Filter.Prefix.Faction:SetChecked(true)
				RT.Filter.Prefix.Faction:SetEnabled(true)
				RT.Filter.Prefix.Faction.Event.CheckboxChange = function()
					if RT.Filter.Prefix.Faction:GetChecked() then
						RT.FilterList.Prefix[1] = true
					else
						RT.FilterList.Prefix[1] = false
					end
				end
				
				
			RT.Filter.Suffix.Faction = UI.CreateFrame("RiftCheckbox", AddonId .. "_Filter_Suffix_Faction", RT.Filter.Category.Faction)
				RT.Filter.Suffix.Faction:SetPoint("TOPLEFT", RT.Filter.Suffix, "BOTTOMLEFT", 5, 5)
				RT.Filter.Suffix.Faction:SetHeight(20)
				RT.Filter.Suffix.Faction:SetWidth(20)
				RT.Filter.Suffix.Faction:SetChecked(true)
				RT.Filter.Suffix.Faction:SetEnabled(true)
				RT.Filter.Suffix.Faction.Event.CheckboxChange = function()
					if RT.Filter.Suffix.Faction:GetChecked() then
						RT.FilterList.Suffix[1] = true
					else
						RT.FilterList.Suffix[1] = false
					end
				end
				
			
			RT.Filter.Category.Incentive = UI.CreateFrame("Text", AddonId .. "_Filter_Category_Incentive", RT.Filter.Category)
				RT.Filter.Category.Incentive:SetPoint("TOPLEFT", RT.Filter.Category.Faction, "BOTTOMLEFT", 0, 5)
				RT.Filter.Category.Incentive:SetFontColor(1,1,1,1)
				RT.Filter.Category.Incentive:SetFontSize(12)
				RT.Filter.Category.Incentive:SetVisible(true)
				RT.Filter.Category.Incentive:SetText("Incentive:")
			
			RT.Filter.Prefix.Incentive = UI.CreateFrame("RiftCheckbox", AddonId .. "_Filter_Prefix_Incentive", RT.Filter.Category.Incentive)
				RT.Filter.Prefix.Incentive:SetPoint("TOPLEFT", RT.Filter.Prefix.Faction, "BOTTOMLEFT", 0, 5)
				RT.Filter.Prefix.Incentive:SetHeight(20)
				RT.Filter.Prefix.Incentive:SetWidth(20)
				RT.Filter.Prefix.Incentive:SetChecked(true)
				RT.Filter.Prefix.Incentive:SetEnabled(true)
				RT.Filter.Prefix.Incentive.Event.CheckboxChange = function()
					if RT.Filter.Prefix.Incentive:GetChecked() then
						RT.FilterList.Prefix[2] = true
					else
						RT.FilterList.Prefix[2] = false
					end
				end
				
			RT.Filter.Suffix.Incentive = UI.CreateFrame("RiftCheckbox", AddonId .. "_Filter_Suffix_Incentive", RT.Filter.Category.Incentive)
				RT.Filter.Suffix.Incentive:SetPoint("TOPLEFT", RT.Filter.Suffix.Faction, "BOTTOMLEFT", 0, 5)
				RT.Filter.Suffix.Incentive:SetHeight(20)
				RT.Filter.Suffix.Incentive:SetWidth(20)
				RT.Filter.Suffix.Incentive:SetChecked(true)
				RT.Filter.Suffix.Incentive:SetEnabled(true)
				RT.Filter.Suffix.Incentive.Event.CheckboxChange = function()
					if RT.Filter.Suffix.Incentive:GetChecked() then
						RT.FilterList.Suffix[2] = true
					else
						RT.FilterList.Suffix[2] = false
					end
				end
				
				
			RT.Filter.Category.Miscellaneous = UI.CreateFrame("Text", AddonId .. "_Filter_Category_Miscellaneous", RT.Filter.Category)
				RT.Filter.Category.Miscellaneous:SetPoint("TOPLEFT", RT.Filter.Category.Incentive, "BOTTOMLEFT", 0, 5)
				RT.Filter.Category.Miscellaneous:SetFontColor(1,1,1,1)
				RT.Filter.Category.Miscellaneous:SetFontSize(12)
				RT.Filter.Category.Miscellaneous:SetVisible(true)
				RT.Filter.Category.Miscellaneous:SetText("Miscellaneous:")
			
			RT.Filter.Prefix.Miscellaneous = UI.CreateFrame("RiftCheckbox", AddonId .. "_Filter_Prefix_Miscellaneous", RT.Filter.Category.Miscellaneous)
				RT.Filter.Prefix.Miscellaneous:SetPoint("TOPLEFT", RT.Filter.Prefix.Incentive, "BOTTOMLEFT", 0, 5)
				RT.Filter.Prefix.Miscellaneous:SetHeight(20)
				RT.Filter.Prefix.Miscellaneous:SetWidth(20)
				RT.Filter.Prefix.Miscellaneous:SetChecked(true)
				RT.Filter.Prefix.Miscellaneous:SetEnabled(true)
				RT.Filter.Prefix.Miscellaneous.Event.CheckboxChange = function()
					if RT.Filter.Prefix.Miscellaneous:GetChecked() then
						RT.FilterList.Prefix[3] = true
					else
						RT.FilterList.Prefix[3] = false
					end
				end
				
			RT.Filter.Suffix.Miscellaneous = UI.CreateFrame("RiftCheckbox", AddonId .. "_Filter_Suffix_Miscellaneous", RT.Filter.Category.Miscellaneous)
				RT.Filter.Suffix.Miscellaneous:SetPoint("TOPLEFT", RT.Filter.Suffix.Incentive, "BOTTOMLEFT", 0, 5)
				RT.Filter.Suffix.Miscellaneous:SetHeight(20)
				RT.Filter.Suffix.Miscellaneous:SetWidth(20)
				RT.Filter.Suffix.Miscellaneous:SetChecked(true)
				RT.Filter.Suffix.Miscellaneous:SetEnabled(true)
				RT.Filter.Suffix.Miscellaneous.Event.CheckboxChange = function()
					if RT.Filter.Suffix.Miscellaneous:GetChecked() then
						RT.FilterList.Suffix[3] = true
					else
						RT.FilterList.Suffix[3] = false
					end
				end
				
				
			RT.Filter.Category.Planar = UI.CreateFrame("Text", AddonId .. "_Filter_Category_Planar", RT.Filter.Category)
				RT.Filter.Category.Planar:SetPoint("TOPLEFT", RT.Filter.Category.Miscellaneous, "BOTTOMLEFT", 0, 5)
				RT.Filter.Category.Planar:SetFontColor(1,1,1,1)
				RT.Filter.Category.Planar:SetFontSize(12)
				RT.Filter.Category.Planar:SetVisible(true)
				RT.Filter.Category.Planar:SetText("Planar:")
			
			RT.Filter.Prefix.Planar = UI.CreateFrame("RiftCheckbox", AddonId .. "_Filter_Prefix_Planar", RT.Filter.Category.Planar)
				RT.Filter.Prefix.Planar:SetPoint("TOPLEFT", RT.Filter.Prefix.Miscellaneous, "BOTTOMLEFT", 0, 5)
				RT.Filter.Prefix.Planar:SetHeight(20)
				RT.Filter.Prefix.Planar:SetWidth(20)
				RT.Filter.Prefix.Planar:SetChecked(true)
				RT.Filter.Prefix.Planar:SetEnabled(true)
				RT.Filter.Prefix.Planar.Event.CheckboxChange = function()
					if RT.Filter.Prefix.Planar:GetChecked() then
						RT.FilterList.Prefix[4] = true
					else
						RT.FilterList.Prefix[4] = false
					end
				end
				
			RT.Filter.Suffix.Planar = UI.CreateFrame("RiftCheckbox", AddonId .. "_Filter_Suffix_Planar", RT.Filter.Category.Planar)
				RT.Filter.Suffix.Planar:SetPoint("TOPLEFT", RT.Filter.Suffix.Miscellaneous, "BOTTOMLEFT", 0, 5)
				RT.Filter.Suffix.Planar:SetHeight(20)
				RT.Filter.Suffix.Planar:SetWidth(20)
				RT.Filter.Suffix.Planar:SetChecked(true)
				RT.Filter.Suffix.Planar:SetEnabled(true)
				RT.Filter.Suffix.Planar.Event.CheckboxChange = function()
					if RT.Filter.Suffix.Planar:GetChecked() then
						RT.FilterList.Suffix[4] = true
					else
						RT.FilterList.Suffix[4] = false
					end
				end
				
				
			RT.Filter.Category.PvP = UI.CreateFrame("Text", AddonId .. "_Filter_Category_PvP", RT.Filter.Category)
				RT.Filter.Category.PvP:SetPoint("TOPLEFT", RT.Filter.Category.Planar, "BOTTOMLEFT", 0, 5)
				RT.Filter.Category.PvP:SetFontColor(1,1,1,1)
				RT.Filter.Category.PvP:SetFontSize(12)
				RT.Filter.Category.PvP:SetVisible(true)
				RT.Filter.Category.PvP:SetText("PvP:")
			
			RT.Filter.Prefix.PvP = UI.CreateFrame("RiftCheckbox", AddonId .. "_Filter_Prefix_PvP", RT.Filter.Category.PvP)
				RT.Filter.Prefix.PvP:SetPoint("TOPLEFT", RT.Filter.Prefix.Planar, "BOTTOMLEFT", 0, 5)
				RT.Filter.Prefix.PvP:SetHeight(20)
				RT.Filter.Prefix.PvP:SetWidth(20)
				RT.Filter.Prefix.PvP:SetChecked(true)
				RT.Filter.Prefix.PvP:SetEnabled(true)
				RT.Filter.Prefix.PvP.Event.CheckboxChange = function()
					if RT.Filter.Prefix.PvP:GetChecked() then
						RT.FilterList.Prefix[5] = true
					else
						RT.FilterList.Prefix[5] = false
					end
				end
				
			RT.Filter.Suffix.PvP = UI.CreateFrame("RiftCheckbox", AddonId .. "_Filter_Suffix_PvP", RT.Filter.Category.PvP)
				RT.Filter.Suffix.PvP:SetPoint("TOPLEFT", RT.Filter.Suffix.Planar, "BOTTOMLEFT", 0, 5)
				RT.Filter.Suffix.PvP:SetHeight(20)
				RT.Filter.Suffix.PvP:SetWidth(20)
				RT.Filter.Suffix.PvP:SetChecked(true)
				RT.Filter.Suffix.PvP:SetEnabled(true)
				RT.Filter.Suffix.PvP.Event.CheckboxChange = function()
					if RT.Filter.Suffix.PvP:GetChecked() then
						RT.FilterList.Suffix[5] = true
					else
						RT.FilterList.Suffix[5] = false
					end
				end
				
				
			RT.Filter.Category.Zone = UI.CreateFrame("Text", AddonId .. "_Filter_Category_Zone", RT.Filter.Category)
				RT.Filter.Category.Zone:SetPoint("TOPLEFT", RT.Filter.Category.PvP, "BOTTOMLEFT", 0, 5)
				RT.Filter.Category.Zone:SetFontColor(1,1,1,1)
				RT.Filter.Category.Zone:SetFontSize(12)
				RT.Filter.Category.Zone:SetVisible(true)
				RT.Filter.Category.Zone:SetText("Zone:")
			
			RT.Filter.Prefix.Zone = UI.CreateFrame("RiftCheckbox", AddonId .. "_Filter_Prefix_Zone", RT.Filter.Category.Zone)
				RT.Filter.Prefix.Zone:SetPoint("TOPLEFT", RT.Filter.Prefix.PvP, "BOTTOMLEFT", 0, 5)
				RT.Filter.Prefix.Zone:SetHeight(20)
				RT.Filter.Prefix.Zone:SetWidth(20)
				RT.Filter.Prefix.Zone:SetChecked(true)
				RT.Filter.Prefix.Zone:SetEnabled(true)
				RT.Filter.Prefix.Zone.Event.CheckboxChange = function()
					if RT.Filter.Prefix.Zone:GetChecked() then
						RT.FilterList.Prefix[6] = true
					else
						RT.FilterList.Prefix[6] = false
					end
				end
				
			RT.Filter.Suffix.Zone = UI.CreateFrame("RiftCheckbox", AddonId .. "_Filter_Suffix_Zone", RT.Filter.Category.Zone)
				RT.Filter.Suffix.Zone:SetPoint("TOPLEFT", RT.Filter.Suffix.PvP, "BOTTOMLEFT", 0, 5)
				RT.Filter.Suffix.Zone:SetHeight(20)
				RT.Filter.Suffix.Zone:SetWidth(20)
				RT.Filter.Suffix.Zone:SetChecked(true)
				RT.Filter.Suffix.Zone:SetEnabled(true)
				RT.Filter.Suffix.Zone.Event.CheckboxChange = function()
					if RT.Filter.Suffix.Zone:GetChecked() then
						RT.FilterList.Suffix[6] = true
					else
						RT.FilterList.Suffix[6] = false
					end
				end
				
				
			RT.Filter.Category.Crafting = UI.CreateFrame("Text", AddonId .. "_Filter_Category_Crafting", RT.Filter.Category)
				RT.Filter.Category.Crafting:SetPoint("TOPLEFT", RT.Filter.Category.Zone, "BOTTOMLEFT", 0, 5)
				RT.Filter.Category.Crafting:SetFontColor(1,1,1,1)
				RT.Filter.Category.Crafting:SetFontSize(12)
				RT.Filter.Category.Crafting:SetVisible(true)
				RT.Filter.Category.Crafting:SetText("Crafting:")
			
			RT.Filter.Prefix.Crafting = UI.CreateFrame("RiftCheckbox", AddonId .. "_Filter_Prefix_Crafting", RT.Filter.Category.Crafting)
				RT.Filter.Prefix.Crafting:SetPoint("TOPLEFT", RT.Filter.Prefix.Zone, "BOTTOMLEFT", 0, 5)
				RT.Filter.Prefix.Crafting:SetHeight(20)
				RT.Filter.Prefix.Crafting:SetWidth(20)
				RT.Filter.Prefix.Crafting:SetEnabled(false)
				
			RT.Filter.Suffix.Crafting = UI.CreateFrame("RiftCheckbox", AddonId .. "_Filter_Suffix_Crafting", RT.Filter.Category.Crafting)
				RT.Filter.Suffix.Crafting:SetPoint("TOPLEFT", RT.Filter.Suffix.Zone, "BOTTOMLEFT", 0, 5)
				RT.Filter.Suffix.Crafting:SetHeight(20)
				RT.Filter.Suffix.Crafting:SetWidth(20)
				RT.Filter.Suffix.Crafting:SetChecked(true)
				RT.Filter.Suffix.Crafting:SetEnabled(true)
				RT.Filter.Suffix.Crafting.Event.CheckboxChange = function()
					if RT.Filter.Suffix.Crafting:GetChecked() then
						RT.FilterList.Suffix[7] = true
					else
						RT.FilterList.Suffix[7] = false
					end
				end
				
end

local function GetConfiguration()

	RT.configTable = {}
	
	RT.configTable.Interval = {}
	RT.configTable.Interval.Count = 1
	RT.configTable.Interval.Type = RT.Time.Option.value:GetText()
	RT.configTable.Interval.Days = RT.Time.Change.Days.value:GetText()
	RT.configTable.Interval.Hours = RT.Time.Change.Hours.value:GetText()
	RT.configTable.Interval.Minutes = RT.Time.Change.Minutes.value:GetText()
	RT.configTable.Interval.Unix = (RT.configTable.Interval.Days*86400)+(RT.configTable.Interval.Hours*3600)+(RT.configTable.Interval.Minutes*60)
	
	RT.configTable.CreateTime = Inspect.Time.Server()
	
	RT.configTable.Category = {}
	RT.configTable.Category.List = { "T0000000153F4479A", "T00000004769D1B6F", "T000000002AC154B4", "T00000005056E4234", "T0000000364066829", "T000000021C63C3DA", "T0000000604529CD5" }
	RT.configTable.Category.Prefix = {}
		for idx = 1, 7 do
			if RT.FilterList.Prefix[idx] then 
				table.insert(RT.configTable.Category.Prefix, RT.configTable.Category.List[idx])
			end
		end

	RT.configTable.Category.Suffix = {}
		for idx = 1, 7 do
			if RT.FilterList.Suffix[idx] then 
				table.insert(RT.configTable.Category.Suffix, RT.configTable.Category.List[idx])
			end
		end
		
	RT.configTable.Title = {}
	RT.configTable.Title.List = Inspect.Title.List()
	RT.configTable.Title.Prefix = {}
		for id,status in pairs(RT.configTable.Title.List) do
			for slot,category in ipairs(RT.configTable.Category.Prefix) do
				if Inspect.Title.Detail(id).category == category and Inspect.Title.Detail(id).prefix then
					table.insert(RT.configTable.Title.Prefix, id)
				end
			end
		end
	RT.configTable.Title.Suffix = {}
		for id,status in pairs(RT.configTable.Title.List) do
			for slot,category in ipairs(RT.configTable.Category.Suffix) do
				if Inspect.Title.Detail(id).category == category and not Inspect.Title.Detail(id).prefix then
					table.insert(RT.configTable.Title.Suffix, id)
				end
			end
		end
	RT.configTable.Title.List = {}

	return RT.configTable
end

local function SetConfiguration(config)
	
	RT.Time.Option.value:SetText(config.Interval.Type)
	RT.Time.Change.Days.value:SetText(tostring(config.Interval.Days))
	RT.Time.Change.Hours.value:SetText(tostring(config.Interval.Hours))
	RT.Time.Change.Minutes.value:SetText(tostring(config.Interval.Minutes))
	
	for cell, data in pairs(RT.Filter.Category:GetChildren()) do
		for child, childdata in pairs(cell:GetChildren()) do
			child:SetChecked(false)
		end
	end
	
	for number, category in pairs(config.Category.Prefix) do
		if category == "T0000000153F4479A" then
			RT.Filter.Prefix.Faction:SetChecked(true)
		elseif category == "T00000004769D1B6F" then
			RT.Filter.Prefix.Incentive:SetChecked(true)
		elseif category == "T000000002AC154B4" then
			RT.Filter.Prefix.Miscellaneous:SetChecked(true)
		elseif category == "T00000005056E4234" then
			RT.Filter.Prefix.Planar:SetChecked(true)
		elseif category == "T0000000364066829" then
			RT.Filter.Prefix.PvP:SetChecked(true)
		elseif category == "T000000021C63C3DA" then
			RT.Filter.Prefix.Zone:SetChecked(true)
		elseif category == "T0000000604529CD5" then
			RT.Filter.Prefix.Crafting:SetChecked(true)
		end
	end
	
	for number, category in pairs(config.Category.Suffix) do
		if category == "T0000000153F4479A" then
			RT.Filter.Suffix.Faction:SetChecked(true)
		elseif category == "T00000004769D1B6F" then
			RT.Filter.Suffix.Incentive:SetChecked(true)
		elseif category == "T000000002AC154B4" then
			RT.Filter.Suffix.Miscellaneous:SetChecked(true)
		elseif category == "T00000005056E4234" then
			RT.Filter.Suffix.Planar:SetChecked(true)
		elseif category == "T0000000364066829" then
			RT.Filter.Suffix.PvP:SetChecked(true)
		elseif category == "T000000021C63C3DA" then
			RT.Filter.Suffix.Zone:SetChecked(true)
		elseif category == "T0000000604529CD5" then
			RT.Filter.Suffix.Crafting:SetChecked(true)
		end
	end
end


WT.Gadget.RegisterFactory("RandomTitle",
{
	name="Random Title",
	description="Random Title Generator",
	author="Noshei",
	version="v1.0.0",
	iconTexAddon=AddonId,
	["Create"] = Create,
	["Reconfigure"] = Modify,
	["ConfigDialog"] = ConfigDialog,
	["GetConfiguration"] = GetConfiguration, 
	["SetConfiguration"] = SetConfiguration, 
})

table.insert(Event.System.Update.Begin,			{ systemUpdate, AddonId, AddonId .. "_systemUpdate" })
table.insert(Event.Title.Add,					{ addTitle, AddonId, AddonId .. "_addTitle" })